# ORCA

ORCA is a flexible, efficient and easy-to-use general purpose tool for quantum chemistry with specific emphasis on spectroscopic properties of open-shell molecules. It features a wide variety of standard quantum chemical methods ranging from semiempirical methods to DFT to single- and multireference correlated ab initio methods. It can also treat environmental and relativistic effects.

## Making orca available

The following module command makes the latest version of orca available to your session

```bash
$ module load ORCA/3_0_3-linux_x86-64
```

**Dependency**

```bash
$ module list
Currently Loaded Modulefiles:
  1) /opt/modules/modulefiles/oscar-modules/1.0.3(default)
  2) GCC/4.9.3-binutils-2.25
  3) binutils/2.25-GCC-4.9.3-binutils-2.25
  4) GNU/4.9.3-2.25
  5) icc/2015.3.187-GNU-4.9.3-2.25
  6) ifort/2015.3.187-GNU-4.9.3-2.25
  7) iccifort/2015.3.187-GNU-4.9.3-2.25
  8) numactl/2.0.10-iccifort-2015.3.187-GNU-4.9.3-2.25
  9) hwloc/1.11.1-iccifort-2015.3.187-GNU-4.9.3-2.25
  10) OpenMPI/1.8.8-iccifort-2015.3.187-GNU-4.9.3-2.25
  11) ORCA/3_0_3-linux_x86-64
```

## Example single core job

Create a file called orca_serial.inp that contains the following orca commands

```cpp
    # My first ORCA calculation :-)
    #
    # Taken from the Orca manual
    # https://orcaforum.cec.mpg.de/OrcaManual.pdf
    ! HF SVP
    * xyz 0 1
      C 0 0 0
      O 0 0 1.13
    *
```

Create a Sun Grid Engine submission file called submit_serial.sh that looks like this

```bash
!/bin/bash

module load ORCA/3_0_3-linux_x86-64
orca orca_serial.inp
```

Submit the job to the queue with the command

```bash
$ qsub -q qexp -I -l select=1
qsub: waiting for job 196821.isrv5 to start
qsub: job 196821.isrv5 ready
[username@r37u04n944 ~]$ ./submit_serial.sh


                                 *****************
                                 * O   R   C   A *
                                 *****************

           --- An Ab Initio, DFT and Semiempirical electronic structure package ---

                  #######################################################
                  #                        -***-                        #
                  #  Department of molecular theory and spectroscopy    #
                  #              Directorship: Frank Neese              #
                  # Max Planck Institute for Chemical Energy Conversion #
                  #                  D-45470 Muelheim/Ruhr              #
                  #                       Germany                       #
                  #                                                     #
                  #                  All rights reserved                #
                  #                        -***-                        #
                  #######################################################

...

                             ****ORCA TERMINATED NORMALLY****
TOTAL RUN TIME: 0 days 0 hours 0 minutes 2 seconds 796 msec
[username@r37u04n944 orca]$ logout

qsub: job 196821.isrv5 completed
```

## Register as a user

You are encouraged to register as a user of Orca at [Here](https://orcaforum.cec.mpg.de/) in order to take advantage of updates, announcements and also of the users forum.

## Documentation

A comprehensive [.pdf](https://orcaforum.cec.mpg.de/OrcaManual.pdf) manual is available online.
